@@ -1,7 +1,6 @@
 module CliqueTrees
 
 using AbstractTrees
-using ArgCheck
 using Base: OneTo, oneto, @kwdef, @propagate_inbounds
 using Base.Iterators
 using Base.Order
@@ -29,11 +28,8 @@ using .MMDLib
 
 const View{T, I} = SubArray{T, 1, Vector{T}, Tuple{UnitRange{I}}, true}
 
-# Linked Lists
-export SinglyLinkedList
-
 # Graphs
-export BipartiteGraph, BipartiteEdgeIter, pointers, targets
+export BipartiteGraph, FBipartiteGraph, BipartiteEdgeIter, pointers, targets
 
 # Lower Bound Algorithms
 export MMW, lowerbound
@@ -74,7 +70,7 @@ export BFS,
     permutation
 
 # Trees
-export Tree, eliminationtree, setrootindex!
+export Tree, FTree, eliminationtree, setrootindex!
 
 # Supernode Types
 export Nodal, Maximal, Fundamental
@@ -86,7 +82,7 @@ export SupernodeTree, supernodetree, residuals
 export Clique, separator, residual
 
 # Clique Trees
-export CliqueTree, cliquetree, treewidth, treefill, separators
+export CliqueTree, cliquetree, treewidth, treefill, separatorwidth, separators
 
 # Abstract Trees
 export rootindices, ancestorindices
@@ -115,6 +111,8 @@ include("filled_edge_iter.jl")
 include("chordal_graphs.jl")
 include("ambiguities.jl")
 include("packages.jl")
+include("mcs_etree.jl")
+include("acsd.jl")
 include("pr3.jl")
 include("pr4.jl")
 include("symb_facts.jl")
