@@ -2,7 +2,7 @@ using AbstractTrees
 using Base: @kwdef, oneto
 using Base.Order
 using CliqueTrees
-using CliqueTrees: DoublyLinkedList, EliminationAlgorithm, Parent, cliquetree!
+using CliqueTrees: SinglyLinkedList, DoublyLinkedList, EliminationAlgorithm, Parent, cliquetree!
 using CliqueTrees.Utilities
 using Graphs
 using Graphs: SimpleEdge
@@ -30,14 +30,15 @@ end
 end
 
 import Catlab
-import libpicosat_jll
 import CryptoMiniSat_jll
 
 @static if Sys.iswindows()
-    import libpicosat_jll as PicoSAT_jll
-    import libpicosat_jll as Lingeling_jll
+    import CryptoMiniSat_jll as libpicosat_jll
+    import CryptoMiniSat_jll as PicoSAT_jll
+    import CryptoMiniSat_jll as Lingeling_jll
     const METIS_OR_KAHYPAR = METISND
 else
+    import libpicosat_jll
     import PicoSAT_jll
     import Lingeling_jll
     const METIS_OR_KAHYPAR = KaHyParND
@@ -546,6 +547,7 @@ end
             SafeRules(; tao=0.9),
             SimplicialRule(; tao=1.0),
             SimplicialRule(; tao=0.9),
+            SafeSeparators(),
             ConnectedComponents(),
             BestWidth(MCS(), MF()),
         )
@@ -612,6 +614,7 @@ end
             SafeRules(; tao=0.9),
             SimplicialRule(; tao=1.0),
             SimplicialRule(; tao=0.9),
+            SafeSeparators(),
             ConnectedComponents(),
             BestWidth(MCS(), MF()),
             BestFill(MCS(), MF()),
@@ -641,6 +644,19 @@ end
     end
 end
 
+@testset "chordality" begin
+    @test  ischordal(smallgraph(:bull))
+    @test  ischordal(smallgraph(:diamond))
+    @test  ischordal(smallgraph(:housex))
+    @test  ischordal(barbell_graph(10, 10))
+    @test  ischordal(binary_tree(10))
+    @test !ischordal(smallgraph(:chvatal))
+    @test !ischordal(smallgraph(:cubical))
+    @test !ischordal(smallgraph(:desargues))
+    @test !ischordal(smallgraph(:dodecahedral) )
+    @test !ischordal(smallgraph(:frucht) )
+end
+
 # Chordal Graphs and Semidefinite Optimization
 # Vandenberghe and Andersen
 @testset "vandenberghe and andersen" begin
@@ -710,7 +726,7 @@ end
                 @inferred CliqueTrees.amf(weights, graph)
                 @inferred CliqueTrees.mlf(weights, graph)
                 @inferred CliqueTrees.mmd(weights, graph)
-                @inferred CliqueTrees.minimalchordal(graph, 1:17, 1:17)
+                @inferred CliqueTrees.mcs_etree(weights, graph, 1:17)
                 @inferred CliqueTrees.pr3(weights, graph, lowerbound(weights, graph))
                 @inferred CliqueTrees.pr4(weights, graph, lowerbound(weights, graph))
                 @inferred CliqueTrees.connectedcomponents(graph)
@@ -746,7 +762,7 @@ end
                 @test_call target_modules = (CliqueTrees,) CliqueTrees.amf(weights, graph)
                 @test_call target_modules = (CliqueTrees,) CliqueTrees.mlf(weights, graph)
                 @test_call target_modules = (CliqueTrees,) CliqueTrees.mmd(weights, graph)
-                @test_call target_modules = (CliqueTrees,) CliqueTrees.minimalchordal(graph, 1:17, 1:17)
+                @test_call target_modules = (CliqueTrees,) CliqueTrees.mcs_etree(weights, graph, 1:17)
                 @test_call target_modules = (CliqueTrees,) CliqueTrees.pr3(weights, graph, lowerbound(weights, graph))
                 @test_call target_modules = (CliqueTrees,) CliqueTrees.pr4(weights, graph, lowerbound(weights, graph))
                 @test_call target_modules = (CliqueTrees,) CliqueTrees.connectedcomponents(graph)
@@ -794,7 +810,7 @@ end
                 @test_opt target_modules = (CliqueTrees,) CliqueTrees.amf(weights, graph)
                 @test_opt target_modules = (CliqueTrees,) CliqueTrees.mlf(weights, graph)
                 @test_opt target_modules = (CliqueTrees,) CliqueTrees.mmd(weights, graph)
-                @test_opt target_modules = (CliqueTrees,) CliqueTrees.minimalchordal(graph, 1:17, 1:17)
+                @test_opt target_modules = (CliqueTrees,) CliqueTrees.mcs_etree(weights, graph, 1:17)
                 @test_opt target_modules = (CliqueTrees,) CliqueTrees.pr3(weights, graph, lowerbound(weights, graph))
                 @test_opt target_modules = (CliqueTrees,) CliqueTrees.pr4(weights, graph, lowerbound(weights, graph))
                 @test_opt target_modules = (CliqueTrees,) CliqueTrees.connectedcomponents(graph)
@@ -896,6 +912,7 @@ end
                         SafeRules(; tao=0.9),
                         SimplicialRule(; tao=1.0),
                         SimplicialRule(; tao=0.9),
+                        SafeSeparators(),
                         ConnectedComponents(),
                         BestWidth(MCS(), MF()),
                         BestFill(MCS(), MF()),
@@ -1127,6 +1144,84 @@ end
     end
 end
 
+@testset "minimal triangulations" begin
+    # Fast Computation of Minimal Fill inside a Given Elimination Ordering
+    # Heggernes and Peyton
+    # Figure 2.1
+    matrix = [
+        0 0 1 1 0 0
+        0 0 1 0 1 0
+        1 1 0 0 0 1
+        1 0 0 0 0 1
+        0 1 0 0 0 1
+        0 0 1 1 1 0
+    ]
+
+    # A Practical Algoithm for Making Fille Graphs Minimal
+    # Blair, Heggernes, and Telle
+    # Figure 2
+    matrix = [
+        0 1 1 0 1 1 0
+        1 0 1 0 1 0 0
+        1 1 0 1 0 0 0
+        0 0 1 0 0 0 1
+        1 1 0 0 0 1 0
+        1 0 0 0 1 0 1
+        0 0 0 1 0 1 0
+    ]
+
+    order = axes(matrix, 2)
+    @test treefill(matrix; alg=MinimalChordal(order)) == 13
+
+    # Minimal Triangulations of Graphs: a Survey
+    # Heggernes
+    # Figure 1
+    matrix = [
+        0 1 0 0 1
+        1 0 1 1 0
+        0 1 0 0 1
+        0 1 0 0 1
+        1 0 1 1 0
+    ]
+ 
+    order = axes(matrix, 2)
+    @test treefill(matrix; alg=MinimalChordal(order)) == 7
+   
+    # The Minimum Degree Heuristic and the Minimal Triangulation Process
+    # Berry, Heggernes, and Simonet
+    # Figure 1
+    matrix = [
+        0 0 0 1 1 0 0
+        0 0 0 1 1 0 0
+        0 0 0 1 1 0 0
+        1 1 1 0 0 1 0
+        1 1 1 0 0 1 1
+        0 0 0 1 1 0 0
+        0 0 0 0 1 0 0
+    ]
+
+    order = axes(matrix, 2)
+    @test treefill(matrix; alg=MinimalChordal(order)) == 10
+
+    # Minimal Triangulation of a Graph and Optimal Pivoting Order in a Sparse Matrix
+    # Ohtsuki, Cheung, and Fujisawa
+    # Figure 3
+    matrix = [
+        0 0 0 0 0 1 1 0 0
+        0 0 0 0 0 0 1 1 0
+        0 0 0 0 0 0 0 1 1
+        0 0 0 0 0 1 1 0 0
+        0 0 0 0 0 0 0 1 1
+        1 0 0 1 0 0 0 0 0
+        1 1 0 1 0 0 0 0 0
+        0 1 1 0 1 0 0 0 0
+        0 0 1 0 1 0 0 0 0
+    ]
+
+    order = axes(matrix, 2)
+    @test treefill(matrix; alg=MinimalChordal(order)) == 12
+end
+
 @testset "fill" begin
     algs = (
         MMD(),
@@ -1166,7 +1261,9 @@ end
             @test fill1 == treefill(tree1)
             @test fill2 == treefill(tree2)
             @test fill3 == treefill(tree3)
-            @test fill1 <= fill2 <= fill3 <= fill
+            @test fill1 <= fill3
+            @test fill2 <= fill3
+            @test fill3 <= fill
         end
     end
 
@@ -1628,7 +1725,7 @@ end
                     @test wlb <= wwidth
                 end
 
-                for outer_alg in (SafeRules,)
+                for outer_alg in (SafeRules, SafeSeparators)
                     for inner_alg in tw_algs
                         alg = outer_alg(inner_alg)
                         @test treewidth(graph; alg) === uwidth
